youtube-dl-server
#################

Run the API server

.. program:: youtube-dl-server

.. option:: -p <port>, --port <port>

	The port the server will use. The default port is 9191

.. option:: -h , --help

	Display the help text

.. option:: --version

	Print the version of the server
